"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.configAdjust = exports.configCreate = void 0;
var lodash_1 = __importDefault(require("lodash"));
var index_1 = require("./index");
/**
 * Creates a client config
 *
 * This is a template that is later used to create a temporary user config
 */
var configCreate = function (server, overrides) {
    return index_1.mergeExisting.keepShapeObject({
        performance: server.performance,
        format: server.format,
        preview: server.preview,
        sorting: server.sorting,
        gallery: server.gallery,
        extensions: server.media.extensions,
        icon: {
            path: server.icon.path,
            mime: server.icon.mime
        },
        style: {
            themes: server.style.themes,
            compact: server.style.compact
        },
        readme: {
            toggled: server.readme.toggled
        },
        debug: server.debug
    }, overrides);
};
exports.configCreate = configCreate;
/**
 * Adjusts a config to make it use client-specific values
 */
var configAdjust = function (config, client) {
    if (lodash_1["default"].isEmpty(client) || !client) {
        return config;
    }
    if (lodash_1["default"].has(client, 'style.compact')
        && typeof client.style.compact === 'boolean') {
        config.style.compact = client.style.compact;
    }
    if (lodash_1["default"].has(config, 'style.themes')
        && lodash_1["default"].isObject(config.style.themes)) {
        if (lodash_1["default"].has(client, 'style.theme')) {
            config.style.themes.set = (!client.style.theme ? false : client.style.theme);
        }
    }
    if (lodash_1["default"].has(client, 'sort')) {
        if (client.sort.row >= 0 && client.sort.row <= 3) {
            switch (parseInt(client.sort.row.toString())) {
                case 0:
                    config.sorting.sortBy = 'name';
                    break;
                case 1:
                    config.sorting.sortBy = 'modified';
                    break;
                case 2:
                    config.sorting.sortBy = 'size';
                    break;
                case 3:
                    config.sorting.sortBy = 'type';
                    break;
            }
            config.sorting.enabled = true;
        }
        if (client.sort.ascending === 0
            || client.sort.ascending === 1) {
            config.sorting.order = (client.sort.ascending === 1 ? 'asc' : 'desc');
            config.sorting.enabled = true;
        }
    }
    if (lodash_1["default"].has(client, 'readme.toggled')) {
        config.readme.toggled = client.readme.toggled;
    }
    return config;
};
exports.configAdjust = configAdjust;
//# sourceMappingURL=configUtils.js.map