"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.handleDotFile = void 0;
/** Vendors */
var chalk_1 = __importDefault(require("chalk"));
var logger_1 = require("./logger");
var index_1 = require("./index");
var ignoreFiles = function (data, itemFilter, excludeExtensions) {
    if (excludeExtensions === void 0) { excludeExtensions = null; }
    /** Store file objects and keys */
    var fileObject = {};
    /** Get all files and directories */
    for (var _i = 0, _a = data.files; _i < _a.length; _i++) {
        var file = _a[_i];
        fileObject[file.name] = file;
    }
    for (var _b = 0, _c = data.directories; _b < _c.length; _b++) {
        var dir = _c[_b];
        fileObject[dir.name + '/'] = dir;
    }
    /** Get file keys */
    var fileKeys = Object.keys(fileObject);
    /** Store lengths */
    var fileKeysLength = fileKeys.length;
    var filterLength = itemFilter.length;
    for (var i = 0; i < filterLength; i++) {
        var ignoreItem = itemFilter[i];
        if (!ignoreItem)
            continue;
        if (Object.prototype.hasOwnProperty.call(fileObject, ignoreItem)) {
            fileObject[ignoreItem].hidden = true;
        }
        else if (ignoreItem.includes('*')) {
            /** Escape input and create new regular expression */
            var ignoreRegex = (0, index_1.wildcardExpression)(ignoreItem);
            for (var i_1 = 0; i_1 < fileKeysLength; i_1++) {
                var key = fileKeys[i_1];
                if (ignoreRegex.test(key)) {
                    fileObject[key].hidden = true;
                }
            }
        }
    }
    if (excludeExtensions.length > 0) {
        for (var _d = 0, _e = data.files; _d < _e.length; _d++) {
            var file = _e[_d];
            if (excludeExtensions.includes(file.extension)) {
                file.hidden = true;
            }
        }
    }
};
var handleDotFile = function (config, data) {
    var _a;
    var metadata = data.metadata, setMetadata = data.setMetadata, files = data.files, directories = data.directories;
    /**	Handle ignored or excluded (file extensions) files */
    if ((config.ignore
        && Array.isArray(config.ignore)
        && config.ignore.length > 0)
        || (config.exclude
            && Array.isArray(config.exclude)
            && config.exclude.length > 0)) {
        var itemFilter = config.ignore && Array.isArray(config.ignore)
            ? config.ignore
            : [];
        var excludeExtensions = config.exclude && Array.isArray(config.exclude)
            ? (config.exclude).map(function (item) { return item.toLowerCase(); })
            : [];
        ignoreFiles({ files: files, directories: directories }, itemFilter, excludeExtensions);
    }
    /** Handle metadata */
    if (config.metadata) {
        /** Get behavior */
        var behavior = ((_a = config.metadataBehavior) === null || _a === void 0 ? void 0 : _a.toLowerCase()) || 'overwrite';
        if (behavior === 'overwrite') {
            /** Set new metadata by merging */
            setMetadata((0, index_1.mergeMetadata)(metadata, config.metadata));
        }
        else if (behavior === 'replace') {
            /** Set new metadata by replacement */
            setMetadata(config.metadata);
        }
        else {
            (0, logger_1.debug)(chalk_1["default"].red("Invalid ".concat(chalk_1["default"].yellow('metadataBehavior'), " ('").concat(chalk_1["default"].yellow(behavior), "') - ignoring.")));
        }
    }
};
exports.handleDotFile = handleDotFile;
//# sourceMappingURL=dotFileUtils.js.map