"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
/** Vendors */
var hover_preview_1 = __importDefault(require("./vendors/hover-preview/hover-preview"));
/** Config */
var config_1 = require("./config/config");
var data_1 = __importDefault(require("./config/data"));
/** Modules */
var logger_1 = require("./modules/logger");
var event_hooks_1 = require("./modules/event-hooks");
/** Classes */
var optimize_1 = __importDefault(require("./classes/optimize"));
/** Components */
var components_1 = require("./components");
/** Helpers */
var helpers_1 = require("./helpers");
/** Stylesheets */
require("../css/root.scss");
require("../css/fonts.scss");
require("../css/main.scss");
/* References */
var selector = data_1["default"].instances.selector;
/* Disable media play */
try {
    navigator.mediaSession.setActionHandler('play', null);
}
catch (error) {
    (0, logger_1.log)('error', error);
}
/* Set main component in data */
data_1["default"].components.main = components_1.componentMain;
/* Set page dom object */
data_1["default"].layer.main = {
    windowHeight: window.innerHeight,
    windowWidth: window.innerWidth,
    scrolledY: window.scrollY,
    /**
    * Updates page data (dimensions etc) — called on resize etc.
    */
    update: function () {
        var table = selector.use('TABLE_CONTAINER');
        data_1["default"].layer.main.windowHeight = window.innerHeight;
        data_1["default"].layer.main.windowWidth = window.innerWidth;
        data_1["default"].layer.main.scrolledY = window.scrollY;
        data_1["default"].layer.main.tableWidth = table.offsetWidth;
        return true;
    }
};
/* Update page values */
data_1["default"].layer.main.update();
/* Enable performance mode */
if (config_1.config.get('performance')) {
    /* Called on row change, updates index properties (for media indexing) */
    var onRowChange_1 = function (rows) {
        var mediaIndex = 0;
        for (var index = 0; index < rows.length; index++) {
            if (rows[index].children[0].children[0].classList.contains('preview')) {
                rows[index]._mediaIndex = mediaIndex;
                mediaIndex++;
            }
        }
    };
    setTimeout(function () {
        requestAnimationFrame(function () {
            /* Create optimize instance */
            data_1["default"].instances.optimize.main = new optimize_1["default"]({
                page: data_1["default"].layer.main,
                table: selector.use('TABLE'),
                scope: [window, 'scrollY'],
                padding: 0,
                on: {
                    rowChange: onRowChange_1
                }
            });
        });
    }, 1);
}
/**
 * Menu click event
 */
event_hooks_1.eventHooks.listen(selector.use('TOP_EXTEND'), 'click', 'sortClick', function (e) {
    data_1["default"].components.main.menu.toggle(e.currentTarget);
});
/**
 * Filter change event
 */
event_hooks_1.eventHooks.listen(selector.use('FILTER_INPUT'), 'input', 'filterInput', function (e) {
    data_1["default"].components.filter.apply(e.currentTarget.value);
});
/**
 * Readme toggle event
 */
if (selector.use('README_CONTAINER')) {
    event_hooks_1.eventHooks.listen(selector.use('README_CONTAINER'), 'toggle', 'toggledReadme', function (e) {
        var client = config_1.user.get();
        if (!client.readme) {
            client.readme = {};
        }
        client.readme.toggled = e.target.hasAttribute('open');
        config_1.user.set(client);
        /**
         * Refresh performance rows
         *
         * This is done because long readme content can lead to a deep set of
         * rows previously being out of view, becoming "visible" without the
         * optimizer rendering them as visible.
         */
        if (data_1["default"].instances.optimize.main.enabled) {
            data_1["default"].instances.optimize.main.attemptRefresh();
        }
    });
}
/**
 * Item click event (show gallery if enabled and table sort)
 */
event_hooks_1.eventHooks.listen(selector.use('TABLE'), 'click', 'sortClick', function (event) {
    var eventTarget = event.target;
    if (eventTarget.tagName === 'SPAN'
        && eventTarget.hasAttribute('sortable')) {
        data_1["default"].components.main.sortTableColumn(eventTarget);
    }
    else if (config_1.config.get('gallery.enabled') === true
        && eventTarget.tagName === 'A'
        && eventTarget.className == 'preview') {
        event.preventDefault();
        var index_1 = 0;
        if (data_1["default"].instances.optimize.main.enabled) {
            /* Get `tr` parent */
            var parent_1 = eventTarget.closest('tr');
            /* Check for a index property, use as index if found */
            if (parent_1._mediaIndex)
                index_1 = parent_1._mediaIndex;
        }
        else {
            selector.use('TABLE').querySelectorAll('tr.file:not(.filtered) a.preview').forEach(function (element, i) {
                if (eventTarget === element)
                    index_1 = i;
            });
        }
        data_1["default"].components.gallery.load(index_1);
    }
});
/**
 * Re-check mobile sizing on resize
 */
event_hooks_1.eventHooks.listen(window, 'resize', 'windowResize', (0, helpers_1.debounce)(function () {
    (0, logger_1.log)('event', 'windowResize (main)', 'Resized');
    /** Get mobile status */
    var isMobile = Modernizr.mq('(max-width: 768px)');
    if (config_1.config.get('mobile') !== isMobile) {
        /** Update mobile status */
        config_1.config.set('mobile', Modernizr.mq('(max-width: 768px)'));
        (0, logger_1.log)('view', "Switched to ".concat(isMobile ? 'mobile' : 'desktop', " view"));
    }
    if (data_1["default"].instances.gallery) {
        data_1["default"].instances.gallery.options.mobile = isMobile;
        data_1["default"].instances.gallery.update.listWidth();
    }
    /* Update page values */
    data_1["default"].layer.main.update();
    /* Refresh performance rows */
    if (data_1["default"].instances.optimize.main.enabled) {
        data_1["default"].instances.optimize.main.attemptRefresh();
    }
}));
/**
 * Create preview events if enabled (and not on mobile)
 */
if (config_1.config.get('mobile') === false
    && config_1.config.get('preview.enabled') === true) {
    var previews_1 = {};
    var resume_1 = null;
    var timerReadyState_1 = null;
    var onLoaded_1 = function (event) {
        (0, logger_1.log)('preview', 'Preview loaded =>', event);
        if (data_1["default"].preview.data
            && data_1["default"].preview.data.element) {
            data_1["default"].preview.data.element.remove();
        }
        if (!data_1["default"].preview.isLoadable)
            return null;
        var _a = [
            event.element,
            event.type,
            event.src
        ], element = _a[0], type = _a[1], src = _a[2];
        data_1["default"].preview.data = event;
        /* Clear timer */
        clearInterval(timerReadyState_1);
        if (element && type === 'VIDEO') {
            /* If a resume is set, then set currentTime */
            if (resume_1 && resume_1.src === src) {
                element.currentTime = resume_1.timestamp;
            }
            else {
                resume_1 = null;
            }
            /* Set stored preview volume */
            (0, helpers_1.setVideoVolume)(element, data_1["default"].preview.volume / 100, false);
            /* Check for valid readystate (4, 3, 2) before we show the video */
            timerReadyState_1 = setInterval(function () {
                if (element.readyState > 1) {
                    /* Show video */
                    helpers_1.DOM.style.set(element, {
                        visibility: 'visible'
                    });
                    /* Clear timer */
                    clearInterval(timerReadyState_1);
                }
            }, 25);
        }
        else {
            /* Not a video, clear resume */
            resume_1 = null;
        }
        /* Store timestamp if exists */
        if (Object.prototype.hasOwnProperty.call(event, 'timestamp')) {
            var timestamp = event.timestamp;
            resume_1 = {
                src: src,
                timestamp: timestamp
            };
        }
        /* If video is audible, enable scrollLock */
        if (event.loaded && event.audible) {
            data_1["default"].scrollLock = true;
        }
        else {
            data_1["default"].scrollLock = false;
        }
    };
    var createPreview_1 = function (element) {
        var src = element.getAttribute('href');
        var extensions = config_1.config.get('extensions');
        var identified = (0, helpers_1.identifyExtension)((0, helpers_1.stripUrl)(src), {
            image: extensions.image,
            video: extensions.video
        });
        if (identified) {
            var extension = identified[0], type = identified[1];
            var options = {};
            /* Delay prior to showing preview */
            options.delay = config_1.config.get('preview.hoverDelay');
            /* Loading cursor */
            options.cursor = config_1.config.get('preview.cursorIndicator');
            /* Encoding */
            options.encodeAll = config_1.config.get('encodeAll');
            /* Events */
            options.on = {
                onLoaded: onLoaded_1
            };
            /* Force set extension data */
            options.force = {
                extension: extension,
                type: type
            };
            /* Create preview */
            previews_1[element.itemIndex] = (0, hover_preview_1["default"])(element, options);
        }
    };
    /* Get previewable elements */
    var previewable = document.querySelectorAll('body > div.tableContainer > table > tbody > tr.file > td > a.preview');
    /* Set preview indexes */
    previewable.forEach(function (preview, index) {
        preview.itemIndex = index;
        if (index === 0)
            createPreview_1(preview);
    });
    /* Add preview hover listener */
    event_hooks_1.eventHooks.listen(selector.use('TABLE'), 'mouseover', 'previewMouseEnter', function (e) {
        /* Check if element is `a` element with a preview class */
        if (e.target.tagName === 'A' && e.target.className == 'preview') {
            var index = (e.target.itemIndex);
            if (!Object.prototype.hasOwnProperty.call(previews_1, index)) {
                createPreview_1(e.target);
            }
        }
    });
}
/* Assign components */
data_1["default"].components.settings = new components_1.componentSettings();
data_1["default"].components.gallery = new components_1.componentGallery();
data_1["default"].components.bind = new components_1.componentBind();
data_1["default"].components.filter = components_1.componentFilter;
/* Create references for bind functions */
data_1["default"].components.main.bind = data_1["default"].components.bind.load;
data_1["default"].components.main.unbind = data_1["default"].components.bind.unbind;
/* Initiate listeners */
data_1["default"].components.main.bind();
/* Load modification dates */
data_1["default"].components.main.dates.load();
/* Reset filter input */
document.body.querySelector(':scope > .filterContainer > input[type="text"]').value = '';
/* Create menu */
var menu = data_1["default"].components.main.menu.create();
/* Get top bar height */
var height = document.querySelector('body > div.topBar').offsetHeight;
/* Set menu styling to match top bar */
if (menu && height) {
    helpers_1.DOM.style.set(menu, {
        top: "".concat(height, "px"),
        visibility: 'unset',
        display: 'none'
    });
}
/* Load sorting indicators */
components_1.componentMain.sort.load();
/* Remove loading state */
document.body.removeAttribute('is-loading');
/* Listen to gallery `bound` event */
event_hooks_1.eventHooks.subscribe('galleryBound', 'mainUnbind', function () {
    /* Gallery is bound, unbind main event handlers */
    data_1["default"].components.main.unbind();
});
/* Listen to gallery `unbound` event */
event_hooks_1.eventHooks.subscribe('galleryUnbound', 'mainBind', function () {
    /* Gallery is unbound, rebind main event handlers */
    data_1["default"].components.main.bind();
});
(0, logger_1.log)('main', 'Config loaded =>', config_1.config.data);
//# sourceMappingURL=main.js.map